@@ -1,9 +1,9 @@
 import os
 import time
-import fonts
-import random
-import models
 from numba import prange
+import random
+from . import fonts
+from . import models
 os.system("cls")
 symbols_list = []
 class Screen():
